pub fn find_python_binary_path(from_dir: Option<PathBuf>) -> HuakResult<String>Expand description
Returns the full path of the python binary in a sepcific order. Python 2 is depcreated so python3 is prefered. If there is no python3 some distributions also rename python3 to simply python. See PEP394 TODO: Refactor to evaluate against each file during the search.